rebotics\_sdk.cli package
=========================

Submodules
----------

rebotics\_sdk.cli.admin module
------------------------------

.. automodule:: rebotics_sdk.cli.admin
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.cli.common module
-------------------------------

.. automodule:: rebotics_sdk.cli.common
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.cli.dataset module
--------------------------------

.. automodule:: rebotics_sdk.cli.dataset
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.cli.renderers module
----------------------------------

.. automodule:: rebotics_sdk.cli.renderers
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.cli.retailer module
---------------------------------

.. automodule:: rebotics_sdk.cli.retailer
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.cli.shelf\_camera\_manager module
-----------------------------------------------

.. automodule:: rebotics_sdk.cli.shelf_camera_manager
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.cli.tasks module
------------------------------

.. automodule:: rebotics_sdk.cli.tasks
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.cli.utils module
------------------------------

.. automodule:: rebotics_sdk.cli.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: rebotics_sdk.cli
    :members:
    :undoc-members:
    :show-inheritance:
